@@ -2,7 +2,7 @@ from . import constants, http
 from models import Strain
 
 
-class Weedmaps:
+class API:
     def __init__(self):
         self.search_url = constants.SEARCH_STRAINS
 
